EOFRotator
==========

.. currentmodule:: xeofs.single

.. autoclass:: EOFRotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EOFRotator.__init__
      ~EOFRotator.components
      ~EOFRotator.compute
      ~EOFRotator.deserialize
      ~EOFRotator.explained_variance
      ~EOFRotator.explained_variance_ratio
      ~EOFRotator.fit
      ~EOFRotator.fit_transform
      ~EOFRotator.get_params
      ~EOFRotator.get_serialization_attrs
      ~EOFRotator.inverse_transform
      ~EOFRotator.load
      ~EOFRotator.save
      ~EOFRotator.scores
      ~EOFRotator.serialize
      ~EOFRotator.singular_values
      ~EOFRotator.transform
   
   

   
   
   